from os import path, makedirs, listdir
from shutil import copy

from PIL import Image


def find_images(dir):
    """Given a directory, finds out which files in the root of the directory are images

    Arguments:
      dir {str} -- directory location to scan for image files

    Raises:
      AssertionError -- if given directory is not valid

    Returns:
      list -- list of filenames found in the given directory which are images
    """
    assert path.isdir(dir)==True

    im_files = []

    for item in listdir(dir):
        item_path = path.normpath(path.join(dir, item))

        if path.isfile(item_path):
            try:
                Image.open(item_path)
                im_files.append(item)
            except IOError:
                pass

    return im_files


def copy_spotlights_images(spotlights_dir, save_dir, split=True, min_res=1920, dir_land="landscape", dir_port="portrait", dir_other="other"):
    """For Windows 10 users, copies beautiful images stored on their machine, called 'Windows Spotlights' to a directory of their choice.

    Arguments:
      spotlights_dir {str} -- directory location where windows 10 stores spotlight images
      save_dir {str} -- directory location where spotlight images will be copied to

    Keyword Arguments:
      split {bool} -- split images into different folders based on types such as landscape and portrait (default: {True})
      min_res {int} -- only include images with width or height greater than or equal to {min_res}
      dir_land {str} -- directory name in which to store landscape images (default: {"landscape"})
      dir_port {str} -- directory name in which to store portrait images (default: {"portrait"})
      dir_other {str} -- directory name in which to store images other than portrait or landscape type (default: {"other"})

    Raises:
      Exception -- raises exception if save_dir is not valid
    """
    if not path.isdir(save_dir):
        raise Exception(f"'{save_dir}' does not seem to be a valid directory!")
    min_res = int(min_res)

    complete_landscape_path, complete_portrait_path, complete_other_path = "", "", ""

    if split:
        # get complete paths to landscape, portrait, and other directories inside the save directory
        complete_landscape_path = path.normpath(path.join(save_dir, dir_land))
        complete_portrait_path = path.normpath(path.join(save_dir, dir_port))
        complete_other_path = path.normpath(path.join(save_dir, dir_other))

        # make required directories if they don't exist
        if not path.isdir(complete_landscape_path):
            makedirs(complete_landscape_path)
        if not path.isdir(complete_portrait_path):
            makedirs(complete_portrait_path)
        if not path.isdir(complete_other_path):
            makedirs(complete_other_path)

    else:
        # don't copy spotlight images into different folders
        complete_landscape_path, complete_portrait_path, complete_other_path = save_dir, save_dir, save_dir

    for image_file in find_images(spotlights_dir):
        image_file_full_path = path.normpath(path.join(spotlights_dir, image_file))

        im = Image.open(image_file_full_path)

        # save image with an extension as read by PIL.Image module
        save_image_file_name = image_file + "." + im.format
        where = None

        im_width, im_height = int(im.size[0]), int(im.size[1])

        if im_width >= min_res or im_height >= min_res:
            if (im_height < im_width):
                where = path.normpath(path.join(complete_landscape_path, save_image_file_name))

            elif (im_width < im_height):
                where = path.normpath(path.join(complete_portrait_path, save_image_file_name))

            else:
                where = path.normpath(path.join(complete_other_path, save_image_file_name))

        if where is not None:
            copy(image_file_full_path, where)



#!/usr/bin/env python3
from copy_spotlights import copy_spotlights_images
from argparse import ArgumentParser
from pathlib import Path


def main():

    # Argument Parser to enable use of this program using bash terminal
    parser = ArgumentParser()
    parser.add_argument("save_dir", type=str, help="directory location where spotlight images will be copied to")
    parser.add_argument("--no-split", dest="no_split", action="store_true", help="portrait and landscape images will not be placed into separate folders")
    parser.add_argument("--min-res", dest="min_res", type=int, help="ignore images with horizontal or vertical resolution lower than min_res value, default:1920", default=1920)
    parser.add_argument("--dir-land", dest="dir_land", type=str, help="directory name in which to store landscape images, default:landscape", default="landscape")
    parser.add_argument("--dir-port", dest="dir_port", type=str, help="directory name in which to store portrait images, default:portrait", default="portrait")
    parser.add_argument("--dir-other", dest="dir_other", type=str, help="directory name in which to store images of equal resolution, default:other", default="other")
    args = parser.parse_args()

    # Known directory location path where windows stores spotlight images
    home = Path.home()
    spotlight_dir = Path.joinpath(home, Path('AppData/Local/Packages/Microsoft.Windows.ContentDeliveryManager_cw5n1h2txyewy/LocalState/Assets'))

    save_dir = args.__getattribute__("save_dir")
    split = not args.__getattribute__("no_split")
    min_res = args.__getattribute__("min_res")
    dir_land = args.__getattribute__("dir_land")
    dir_port = args.__getattribute__("dir_port")
    dir_other = args.__getattribute__("dir_other")

    copy_spotlights_images(spotlight_dir, save_dir, split, min_res, dir_land, dir_port, dir_other)


if __name__ == "__main__":
    main()



from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='get-spotlights',
    version='3.1',
    install_requires='pillow',
    packages=['copy_spotlights'],
    entry_points = {
        "console_scripts": [
            "get-spotlights = copy_spotlights.command_line:main",
        ],
        "gui_scripts": [
            "get-spotlights-gui = copy_spotlights.gui:main",
        ],
    },
    url='https://github.com/ksharshveer/copy-windows10-spotlight-images',
    license='MIT',
    author='Harshveer Singh',
    author_email='ksharshveer@gmail.com',
    description='Love windows 10 spotlight images that show up on lock-screen. Then here\'s a simple program to copy those images and get them in your preferred directory.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords='copy extract get windows 10 spotlight spotlights image images lockscreen wallpaper',
)



from tkinter import Tk, Label, Button, Entry, Checkbutton, filedialog
from pathlib import Path
from copy_spotlights import copy_spotlights_images

# default padding settings
px = 20
py = 10


class MyGui:

    def __init__(self):

        self.window = Tk()
        self.window.title('Extract Spotlight Images')

        # setting default values for variables
        self.home = Path.home()
        self.source_location = Path.joinpath(self.home, Path('AppData/Local/Packages/Microsoft.Windows.ContentDeliveryManager_cw5n1h2txyewy/LocalState/Assets'))
        self.save_location = Path.joinpath(self.home, Path('Desktop'))
        self.split = True
        self.min_res = 1920

        # setting up buttons and their actions
        self.b_save = Button(self.window, text="Save Location", command=self.set_save_location)
        self.b_source = Button(self.window, text="Spotlights source", command=self.set_source_location)
        self.b_reset = Button(self.window, text="Set Defaults", command=self.reset)
        self.b_split = Checkbutton(self.window, text="Don't split", command=self.toggle_split)
        self.b_min_res = Entry(self.window, textvariable=self.min_res)
        self.b_main = Button(self.window, text="Get Spotlights", command=self.copy_spotlights, fg="white", bg="green", bd=4)

        # setting up labels to represent button actions
        self.l_save = Label(self.window, text=self.save_location)
        self.l_source = Label(self.window, text=self.source_location)
        self.l_settings = Label(self.window, text="Advanced Settings below :")
        self.l_split = Label(self.window, text="If checked, landscape and portrait image will not be separated")
        self.l_min_res = Label(self.window, text="Only include images with width or height greater than or equal to this value")

        self.setup_button_layouts()
        self.setup_label_layouts()

        self.window.mainloop()

    def setup_button_layouts(self):
        self.b_save.grid(row=0, column=0, padx=px, pady=py)
        self.b_source.grid(row=3, column=0, padx=px, pady=py)
        self.b_min_res.grid(row=5, column=0, padx=px, pady=py)
        self.b_min_res.insert(0, self.min_res)
        self.b_reset.grid(row=6, column=0, padx=px, pady=py)
        self.b_split.grid(row=4, column=0, padx=px, pady=py)
        self.b_main.grid(row=1, columnspan=2, padx=2*px, pady=2*py)

    def setup_label_layouts(self):
        self.l_save.grid(row=0, column=1, padx=px, pady=py)
        self.l_source.grid(row=3, column=1, padx=px, pady=py)
        self.l_split.grid(row=4, column=1, padx=px, pady=py)
        self.l_settings.grid(row=2, column=0, padx=px, pady=py)
        self.l_source.grid(row=3, column=1, padx=px, pady=py)
        self.l_min_res.grid(row=5, column=1, padx=px, pady=py)

    def update_labels(self):
        self.l_save.destroy()
        self.l_save = Label(self.window, text=self.save_location)
        self.l_source.destroy()
        self.l_source = Label(self.window, text=self.source_location)
        self.setup_label_layouts()

    def set_source_location(self):
        source_location = filedialog.askdirectory()
        if source_location:
            self.source_location = source_location
        self.update_labels()

    def set_save_location(self):
        save_location = filedialog.askdirectory()
        if save_location:
            self.save_location = save_location
        self.update_labels()

    def toggle_split(self):
        self.split = False if self.split else True

    def copy_spotlights(self):
        min_res = self.b_min_res.get()
        if min_res:
            self.min_res = min_res
        copy_spotlights_images(self.source_location, self.save_location, self.split, self.min_res)
        self.popup_finished()

    @staticmethod
    def popup_finished():
        done = Tk()
        Label(done, text="Finished!").grid(row=0, columnspan=3, padx=2*px, pady=py)
        Button(done, text="Ok", command=done.destroy).grid(row=1, column=1, padx=px)

    def reset(self):
        self.window.destroy()
        self.__init__()


def main():
    MyGui()


if __name__ == '__main__':
    main()
